==> nextcloud-31.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/user_status/l10n/pt_BR.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Status recentes",
    "No recent status changes" : "Sem alterações de status recentes",
    "In a meeting" : "Em reunião",
    "Commuting" : "Em trânsito",
    "Out sick" : "Doente",
    "Vacationing" : "Férias",
    "Out of office" : "Fora do escritório",
    "Working remotely" : "Em trabalho remoto",
    "In a call" : "Numa chamada",
    "User status" : "Status do usuário",
    "Clear status after" : "Limpar status após",
    "Emoji for your status message" : "Emoji para sua mensagem de status",
    "What is your status?" : "Qual é o seu status?",
    "Predefined statuses" : "Status predefinidos",
    "Previously set" : "Definido anteriormente",
    "Reset status" : "Reinicie o status",
    "Reset status to \"{icon} {message}\"" : "Redefinir status para \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Redefinir status para \"{message}\"",
    "Reset status to \"{icon}\"" : "Redefinir status para \"{icon}\"",
    "There was an error saving the status" : "Ocorreu um erro ao salvar o status",
    "There was an error clearing the status" : "Ocorreu um erro ao limpar o status",
    "There was an error reverting the status" : "Ocorreu um erro ao reverter o status",
    "Set status" : "Definir status",
    "Online status" : "Status online",
    "Status message" : "Mensagem de status",
    "Set absence period" : "Definir período de ausência",
    "Set absence period and replacement" : "Definir período de ausência e substituição",
    "Your status was set automatically" : "Seu status foi definido automaticamente",
    "Clear status message" : "Limpar mensagem de status",
    "Set status message" : "Definir mensagem de status",
    "Don't clear" : "Não limpar",
    "Today" : "Hoje",
    "This week" : "Esta semana",
    "Online" : "Online",
    "Away" : "Fora",
    "Do not disturb" : "Não perturbe",
    "Invisible" : "Invisível",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Ocorreu um erro ao salvar o novo status",
    "30 minutes" : "30 minutos",
    "1 hour" : "1 hora",
    "4 hours" : "4 horas",
    "Mute all notifications" : "Silenciar todas as notificações",
    "Appear offline" : "Aparecer offline"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/user_status/l10n/pt_BR.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Status recentes",
    "No recent status changes" : "Sem alterações de status recentes",
    "In a meeting" : "Em reunião",
    "Commuting" : "Em trânsito",
    "Out sick" : "Doente",
    "Vacationing" : "Férias",
    "Out of office" : "Fora do escritório",
    "Working remotely" : "Em trabalho remoto",
    "In a call" : "Em uma chamada",
    "User status" : "Status do usuário",
    "Clear status after" : "Limpar status após",
    "Emoji for your status message" : "Emoji para sua mensagem de status",
    "What is your status?" : "Qual é o seu status?",
    "Predefined statuses" : "Status predefinidos",
    "Previously set" : "Definido anteriormente",
    "Reset status" : "Redefinir status",
    "Reset status to \"{icon} {message}\"" : "Redefinir status para \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Redefinir status para \"{message}\"",
    "Reset status to \"{icon}\"" : "Redefinir status para \"{icon}\"",
    "There was an error saving the status" : "Ocorreu um erro ao salvar o status",
    "There was an error clearing the status" : "Ocorreu um erro ao limpar o status",
    "There was an error reverting the status" : "Ocorreu um erro ao reverter o status",
    "Set status" : "Definir status",
    "Online status" : "Status online",
    "Status message" : "Mensagem de status",
    "Set absence period" : "Definir período de ausência",
    "Set absence period and replacement" : "Definir período de ausência e substituição",
    "Your status was set automatically" : "Seu status foi definido automaticamente",
    "Clear status message" : "Limpar mensagem de status",
    "Set status message" : "Definir mensagem de status",
    "Don't clear" : "Não limpe",
    "Today" : "Hoje",
    "This week" : "Esta semana",
    "Online" : "Online",
    "Away" : "Fora",
    "Do not disturb" : "Não perturbe",
    "Invisible" : "Invisível",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Ocorreu um erro ao salvar o novo status",
    "30 minutes" : "30 minutos",
    "1 hour" : "1 hora",
    "4 hours" : "4 horas",
    "Mute all notifications" : "Silenciar todas as notificações",
    "Appear offline" : "Aparecer offline"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
